# coding: utf-8

"""
    Mentortools Landing Page API

    Mentortools service for building and publishing landing pages

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from landing_page_server_connector.models.response_wrapper_landing_get import ResponseWrapperLandingGet  # noqa: E501

class TestResponseWrapperLandingGet(unittest.TestCase):
    """ResponseWrapperLandingGet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperLandingGet:
        """Test ResponseWrapperLandingGet
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperLandingGet`
        """
        model = ResponseWrapperLandingGet()  # noqa: E501
        if include_optional:
            return ResponseWrapperLandingGet(
                done = True,
                result = landing_page_server_connector.models.landing_get.LandingGet(
                    html = '', 
                    css = '', 
                    js = '', 
                    components = landing_page_server_connector.models.components.Components(), 
                    styles = [
                        None
                        ], 
                    assets = [
                        None
                        ], 
                    theme = landing_page_server_connector.models.theme.Theme(), 
                    name = '', 
                    title = '', 
                    path = '', 
                    order = 56, 
                    editor_version = null, 
                    portal_id = 56, 
                    id = 56, 
                    funnel_id = 56, 
                    uuid = '', 
                    preview_id = '', 
                    google_analytics_pixel = '', 
                    google_tag_manager_pixel = '', 
                    facebook_pixel = '', 
                    tiktok_pixel = '', 
                    pinterest_pixel = '', 
                    custom_scripts = [
                        landing_page_server_connector.models.landing_script_get.LandingScriptGet(
                            elements = [
                                landing_page_server_connector.models.script_element.ScriptElement(
                                    tag = '', 
                                    content = '', 
                                    src = '', 
                                    href = '', 
                                    rel = '', )
                                ], 
                            title = '', 
                            category = 'analytics', 
                            placement = 'body', 
                            elements_str = '', )
                        ], 
                    requires_correction = True, 
                    is_homepage = True, 
                    noindex = True, 
                    created_at = 56, 
                    updated_at = 56, 
                    published_at = 56, ),
                error = ''
            )
        else:
            return ResponseWrapperLandingGet(
                done = True,
        )
        """

    def testResponseWrapperLandingGet(self):
        """Test ResponseWrapperLandingGet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
