# coding: utf-8

"""
    Mentortools Landing Page API

    Mentortools service for building and publishing landing pages

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from landing_page_server_connector.models.landing_list_get import LandingListGet  # noqa: E501

class TestLandingListGet(unittest.TestCase):
    """LandingListGet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LandingListGet:
        """Test LandingListGet
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LandingListGet`
        """
        model = LandingListGet()  # noqa: E501
        if include_optional:
            return LandingListGet(
                id = 56,
                portal_id = 56,
                funnel_id = 56,
                order = 56,
                uuid = '',
                editor_version = 1,
                name = '',
                title = '',
                path = '',
                preview_id = '',
                requires_correction = True,
                is_homepage = True,
                noindex = True,
                created_at = 56,
                updated_at = 56,
                published_at = 56
            )
        else:
            return LandingListGet(
                id = 56,
                portal_id = 56,
                order = 56,
                uuid = '',
                editor_version = 1,
                name = '',
                title = '',
                path = '',
                requires_correction = True,
                is_homepage = True,
                noindex = True,
                created_at = 56,
        )
        """

    def testLandingListGet(self):
        """Test LandingListGet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
