# coding: utf-8

"""
    Mentortools Landing Page API

    Mentortools service for building and publishing landing pages

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictBool, StrictStr

class InputField(BaseModel):
    """
    InputField
    """
    name: Optional[StrictStr] = None
    required: Optional[StrictBool] = False
    placeholder: Optional[StrictStr] = ''
    type: Optional[StrictStr] = ''
    value: Optional[StrictStr] = ''
    checked: Optional[StrictBool] = False
    __properties = ["name", "required", "placeholder", "type", "value", "checked"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> InputField:
        """Create an instance of InputField from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> InputField:
        """Create an instance of InputField from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return InputField.parse_obj(obj)

        _obj = InputField.parse_obj({
            "name": obj.get("name"),
            "required": obj.get("required") if obj.get("required") is not None else False,
            "placeholder": obj.get("placeholder") if obj.get("placeholder") is not None else '',
            "type": obj.get("type") if obj.get("type") is not None else '',
            "value": obj.get("value") if obj.get("value") is not None else '',
            "checked": obj.get("checked") if obj.get("checked") is not None else False
        })
        return _obj


